import React from 'react'
/**
 * @description Wrap表单配置信息
 */
export default function (wrap, columns) {
  let roleList = sessionStorage.getItem('sysRoles')
  let appType = sessionStorage.getItem('appType')
  let isprint = sessionStorage.getItem('MenuType') === 'billPrint'
  let ispop = sessionStorage.getItem('editMenuType') === 'popview'

  if (roleList) {
    try {
      roleList = JSON.parse(roleList)
    } catch (e) {
      roleList = []
    }
  } else {
    roleList = []
  }

  let menulist = sessionStorage.getItem('fstMenuList')
  if (menulist) {
    try {
      menulist = JSON.parse(menulist)
    } catch (e) {
      menulist = []
    }
  } else {
    menulist = []
  }

  const calendarWrapForm = [
    {
      type: 'text',
      field: 'title',
      label: '标题',
      initval: wrap.title || '',
      required: false
    },
    {
      type: 'text',
      field: 'name',
      label: '组件名称',
      initval: wrap.name || '',
      tooltip: '用于组件间的区分。',
      required: true
    },
    {
      type: 'number',
      field: 'width',
      label: '宽度',
      initval: wrap.width || 24,
      tooltip: '栅格布局，每行等分为24列。',
      min: 1,
      max: 24,
      precision: 0,
      required: true
    },
    {
      type: 'checkbox',
      field: 'levels',
      label: '日历等级',
      initval: wrap.levels || [],
      required: true,
      options: [
        {value: 'day', label: '日'},
        {value: 'month', label: '月'},
        {value: 'year', label: '年'},
      ]
    },
    {
      type: 'select',
      field: 'timeField',
      label: '时间字段',
      initval: wrap.timeField || '',
      tooltip: '数据中的时间字段，用于在日历中标记事件位置。',
      required: true,
      options: columns
    },
    {
      type: 'select',
      field: 'endField',
      label: '结束时间',
      initval: wrap.endField || '',
      tooltip: '数据中事件的结束时间，用于在日历中标记事件位置。',
      required: false,
      options: columns
    },
    {
      type: 'select',
      field: 'remarkField',
      label: '信息字段',
      initval: wrap.remarkField || '',
      required: true,
      options: columns
    },
    {
      type: 'select',
      field: 'colorField',
      label: '颜色字段',
      initval: wrap.colorField || '',
      required: false,
      options: columns,
      controlFields: [
        {field: 'signs', notNull: true},
      ]
    },
    {
      type: 'radio',
      field: 'permission',
      label: '权限验证',
      initval: wrap.permission || (!appType ? 'true' : 'false'),
      required: false,
      options: [
        {value: 'true', label: !appType ? '继承菜单' : '启用'},
        {value: 'false', label: '禁用'},
      ],
      forbid: ispop || isprint
    },
    {
      type: 'radio',
      field: 'cacheLocal',
      label: '本地缓存',
      initval: wrap.cacheLocal || 'true',
      required: false,
      options: [
        {value: 'true', label: '继承菜单'},
        {value: 'false', label: '禁用'},
      ],
      forbid: ispop || isprint
    },
    {
      type: 'radio',
      field: 'cacheSearch',
      label: '搜索缓存',
      initval: wrap.cacheSearch || 'false',
      tooltip: '启用搜索条件缓存后，在菜单刷新时搜索条件不变。',
      required: false,
      options: [
        {value: 'true', label: '启用'},
        {value: 'false', label: '禁用'},
      ],
      forbid: !!appType || isprint
    },
    {
      type: 'radio',
      field: 'click',
      label: '点击事件',
      initval: wrap.click || '',
      tooltip: '可通过点击事件跳转至指定页面。',
      required: false,
      options: [
        {value: '', label: '无'},
        {value: 'menu', label: '菜单'},
        {value: 'menus', label: '菜单组'}
      ],
      controlFields: [
        {field: 'menu', values: ['menu']},
        {field: 'menuType', values: ['menus']},
        {field: 'menus', values: ['menus']},
      ],
      forbid: isprint
    },
    {
      type: 'select',
      field: 'menuType',
      label: '菜单类型',
      initval: wrap.menuType || '',
      required: true,
      options: columns,
      forbid: isprint
    },
    {
      type: 'cascader',
      field: 'menu',
      label: '关联菜单',
      initval: wrap.menu || [],
      required: true,
      extendName: 'MenuNo',
      options: menulist,
      forbid: isprint
    },
    {
      type: 'multiselect',
      field: 'blacklist',
      label: '黑名单',
      initval: wrap.blacklist || [],
      required: false,
      options: roleList,
      forbid: !!appType || isprint
    },
    {
      type: 'table',
      field: 'signs',
      label: '颜色标识',
      initval: wrap.signs || [],
      required: false,
      span: 24,
      columns: [
        {
          title: '标识',
          dataIndex: 'sign',
          inputType: 'input',
          editable: true,
          unique: true,
          required: false,
          width: '30%'
        },
        {
          title: '颜色',
          dataIndex: 'background',
          inputType: 'color',
          editable: true,
          required: true,
          render: (text, record) => (<div style={{background: text, width: '100px', height: '25px'}}></div>),
          width: '40%'
        }
      ]
    },
    {
      type: 'table',
      field: 'menus',
      label: '菜单组',
      initval: wrap.menus || [],
      required: true,
      span: 24,
      actions: ['view'],
      forbid: isprint,
      columns: [
        {
          title: '标识',
          dataIndex: 'sign',
          inputType: 'input',
          editable: true,
          unique: true,
          required: false,
          width: '30%'
        },
        {
          title: '菜单',
          dataIndex: 'menu',
          inputType: 'cascader',
          editable: true,
          required: true,
          extends: 'Menu',
          width: '40%',
          render: (text, record) => record.label,
          options: menulist
        }
      ]
    },
  ]

  return calendarWrapForm
} 